#!/usr/bin/Rscript

# print(snakemake)

## LOG FILE
# sink(file=file(snakemake@log$out, open="wt"), type="output")
# sink(file=file(snakemake@log$err, open="wt"), type="message")

## NOTE
# XXX

## IMPORT
suppressMessages(library(testit)) # assertions
# suppressMessages(library(tools))
# suppressMessages(library(gtools))
# suppressMessages(library(rjson))
# suppressMessages(library(rmarkdown)) #Rmarkdown
# suppressMessages(library(knitr))
# suppressMessages(library(DT))
# suppressMessages(require(grid))
suppressMessages(library(ggplot2)) # plotting
suppressMessages(library(reshape2)) # reshaping dataframes
suppressMessages(library(scales)) # plot scales
suppressMessages(library(pheatmap)) # heatmaps
suppressMessages(require(grid)) # for heatmaps
suppressMessages(library(viridis)) # color palette

# custom
# source("workflow_report/scripts/utils.R")

# names
ASM_TOOL_NAMES <- c(
    "flye"="Flye",
    "wtdbg2"="wtdbg2",
    "canu"="Canu",
    "flye_sr"="Flye + racon(SR)",
    "wtdbg2_sr"="wtdbg2 + racon(SR)",
    "canu_sr"="Canu + racon(SR)",
    "megahit"="MEGAHIT",
    "metaspades"="metaSPAdes",
    "operams"="OPERA-MS",
    "metaspadeshybrid"="metaSPAdes (H)",
    "operams_sr"="OPERA-MS + racon(SR)",
    "metaspadeshybrid_sr"="metaSPAdes (H) + racon(SR)",
    "imp3"="IMP3 (MG/MT)"
)
# colors
ASM_TOOL_PALETTE1 <- ggsci::pal_nejm("default", alpha=1)(8)
ASM_TOOL_PALETTE2 <- ggsci::pal_nejm("default", alpha=0.8)(8)
ASM_TOOL_COLORS <- c(
    "Flye"=ASM_TOOL_PALETTE2[1],
    "wtdbg2"=ASM_TOOL_PALETTE2[2],
    "Canu"=ASM_TOOL_PALETTE2[3],
    "Flye + racon(SR)"=ASM_TOOL_PALETTE1[1],
    "wtdbg2 + racon(SR)"=ASM_TOOL_PALETTE1[2],
    "Canu + racon(SR)"=ASM_TOOL_PALETTE1[3],
    "MEGAHIT"=ASM_TOOL_PALETTE1[4],
    "metaSPAdes"=ASM_TOOL_PALETTE1[5],
    "OPERA-MS"=ASM_TOOL_PALETTE2[6],
    "metaSPAdes (H)"=ASM_TOOL_PALETTE2[7],
    "OPERA-MS + racon(SR)"=ASM_TOOL_PALETTE1[6],
    "metaSPAdes (H) + racon(SR)"=ASM_TOOL_PALETTE1[7],
    "IMP3 (MG/MT)"=ASM_TOOL_PALETTE1[8]
)
ASM_TOOL_COLORS <- ASM_TOOL_COLORS[ASM_TOOL_NAMES]


## DATA
df <- read.csv(
    file="notes/cdhit_uniq_stats_GDB.tsv",
    sep="\t",
    header=TRUE,
    check.names=FALSE,
    stringsAsFactors=FALSE
)
df$tool1 <- ASM_TOOL_NAMES[df$tool1]
df$tool2 <- ASM_TOOL_NAMES[df$tool2]
df$tool1 <- factor(df$tool1, ordered=TRUE, levels=ASM_TOOL_NAMES)
df$tool2 <- factor(df$tool2, ordered=TRUE, levels=ASM_TOOL_NAMES)

## PLOT
pps <- list()
for(pn in c("gene_total_count", "gene_ave_length", "cluster_gene_total_count", "cluster_gene_total_pct", "cluster_gene_ave_count", "cluster_gene_ave_length")){
    pps[[pn]] <-
        ggplot(data=df, aes_string(x="tool2", y=pn, fill="tool2")) +
        geom_col() +
        facet_wrap(vars(tool1), ncol=1) +
        scale_fill_manual(values=ASM_TOOL_COLORS, guide=NULL) +
        labs(
            subtitle=pn,
            x="Assembly 2",
            y="Proteins from Assembly 2 not in Assembly 1"
        ) +
        cdhit_theme
}

## PDF
pdf("notes/cdhit_uniq_stats_GDB.pdf", width=16, height=16)
for(pp in pps){ print(pp) }
dev.off()
