#!/usr/bin/env python

# NOTE: This is a test script to filter DIAMOND results and get subject annotations from the corresponding database FASTA file
# NOTE: requirements: pandas, Biopython (use RGI's conda env.)
# NOTE: Used FASTA has 167,761,270 entries
# 
# TEST:
# conda env.: /home/users/vgalata/miniconda3/envs/ONT_pilot/pipeline/33951b18
# input:
#   grep "^>" /work/projects/ecosystem_biology/local_tools/databases/uniprot_trembl.fasta > /scratch//users/vgalata/uniprot_trembl.fasta.tsv
#   sed -i "s/^>//" /scratch//users/vgalata/uniprot_trembl.fasta.tsv
#   sed -i "s/\s\+/\t/" /scratch//users/vgalata/uniprot_trembl.fasta.tsv
# python diamond_annot.py /scratch/users/vgalata/GDB/results/annotation/diamond/sr/megahit/proteins.tsv /scratch//users/vgalata/uniprot_trembl.fasta.tsv /scratch/users/vgalata/GDB/results/annotation/diamond/sr/megahit/proteins.filtered.annot.tsv
# python diamond_annot.py /scratch/users/vgalata/GDB/results/annotation/diamond/lr/flye/proteins.tsv /scratch//users/vgalata/uniprot_trembl.fasta.tsv /scratch/users/vgalata/GDB/results/annotation/diamond/lr/flye/proteins.filtered.annot.tsv

import sys
from datetime import datetime
from utils import parse_diamond_tsv
# from Bio import SeqIO

def mynow():
    return datetime.now().strftime("%H:%M:%S")

if __name__ == "__main__":
    # parse hits
    hits = parse_diamond_tsv(sys.argv[1])
    print("{} read in {} hits\n{}\n".format(mynow(), hits.shape[0], hits.head()))
    # filter hits
    hits = hits.loc[hits.qs_len_ratio <= 0.5,:]
    print("{} kept in {} hits\n{}\n".format(mynow(), hits.shape[0], hits.head()))
    # add annotation
    sseqids = set(hits.sseqid)
    sdescr  = dict.fromkeys(sseqids, None)
    progress = 0
    with open(sys.argv[2], "r") as ifile:
        for line in ifile:
            line_id, line_descr = line.rstrip().split("\t")
            if line_id in sseqids:
                sdescr[line_id] = line_descr
            progress += 1
            if progress % 100000 == 0:
                print ("Processed {} DB entries".format(progress), end="\r")
    print("{} collected subject info".format(mynow()))
    hits = hits.assign(sdescr=hits.sseqid.apply(lambda x: sdescr[x]))
    print("{} added subject info\n{}\n".format(mynow(), hits.head()))
    # write to file
    hits.to_csv(sys.argv[3], sep="\t", header=True, index=False, index_label=False)
