#!/usr/bin/Rscript

## LOG FILE
sink(file=file(snakemake@log[[1]], open="wt"), type="message")

## NOTE
# UpSetR
# https://cran.r-project.org/web/packages/UpSetR/vignettes/basic.usage.html

## IMPORT
# suppressMessages(library(testit))
suppressMessages(library(UpSetR))
# custom
source(snakemake@params$utils)

## DATA
# overlap/intersection sizes
overlap_sizes <- read.csv(
    file=snakemake@input$overlap_sizes,
    sep=" ",
    header=FALSE,
    stringsAsFactors=FALSE
)
# check: all expected tools are there
# testit::assert(all(sapply(names(ASM_TOOL_NAMES), function(x){ x %in% overlap_sizes$V2 })))
# process names
for(tname in names(ASM_TOOL_NAMES)){
    overlap_sizes$V2 <- sub(tname, ASM_TOOL_NAMES[tname], overlap_sizes$V2)
}
overlap_sizes$V2 <- gsub("_", "&", overlap_sizes$V2)
# create input for UpSetR
overlap_names <- overlap_sizes$V2
overlap_sizes <- overlap_sizes$V1
names(overlap_sizes) <- overlap_names

## PLOT
pdf(snakemake@output$pdf, width=snakemake@params$width, height=snakemake@params$height, onefile=FALSE)
UpSetR::upset(
    data=UpSetR::fromExpression(overlap_sizes),
    # overlap order
    order.by="degree",
    decreasing=FALSE,
    # colors
    set.metadata=list(
        data=data.frame(
            sets=ASM_TOOL_NAMES_NOTMETH,
            Tool=ASM_TOOL_NAMES_NOTMETH,
            stringsAsFactors=FALSE
        ), 
        plots=list(list(type="matrix_rows", column="Tool", colors=ASM_TOOL_COLORS$notmeth, alpha=0.7))
    )
)
dev.off()
